#
# spec file for package boinc-client
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 by Sascha Manns <saigkill@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Global definitions
%define _use_internal_dependency_generator 0
%define __find_requires %{wx_requires}
%define soname 7
%define boinc_dir %{_localstatedir}/lib/boinc
Name:           boinc-client
Version:        7.2.42
Release:        4.6
Summary:        The BOINC client
License:        GPL-3.0+ or LGPL-3.0+
Group:          Productivity/Clustering/Computing
Url:            http://boinc.berkeley.edu/
# There is no real tarball, hence I did
#
# git clone git://boinc.berkeley.edu/boinc.git
# git checkout master
# git checkout -t client_release/7.2/7.2.42
#
# then I created an archive via git
#
# git archive -v --format=tar --prefix=boinc-7.2.42/ \
#  client_release/7.2/7.2.42 | bzip2 >../boinc-7.2.42.tar.bz2
Source0:        boinc-%{version}.tar.bz2
Source1:        boinc-icons.tar.bz2
Source2:        boinc-gui.desktop
Source3:        README.SUSE
Source4:        sysconfig.%{name}
Source5:        boinc-logrotate
Source6:        boinc-manager
# The source for this package was pulled from upstream's vcs. Use the
# following commands to generate the tarball:
#
# ./generate-tarball.sh boinc_core_release_VERSION
#
# Trim all binaries and other unnecessary things.
Source8:        generate-tarball.sh
Source20:       %{name}.service
Source100:      %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE boinc-guirpcauth.patch
# Create password file rw for group, this enables passwordless connection
# of manager from users of the boinc group.
# This won't be probably upstreamed as it might be unsafe for common usage
# without setting proper group ownership of the password file.
Patch0:         boinc-guirpcauth.patch
# PATCH-FIX-OPENSUSE boinc-LC_MESSAGES.patch
Patch2:         boinc-LC_MESSAGES.patch
# PATCH-FIX-OPENSUSE boinc-docbook2x.patch
Patch4:         boinc-docbook2x.patch
# PATCH-FIX-OPENSUSE coolo - #error: am__fastdepOBJCXX does not appear in AM_CONDITIONAL
Patch7:         %{name}-AM_CONDITIONAL.patch
# PATCH-FIX-OPENSUSE computersalat - error:
# configure.ac:898: required file `test/version.inc.in' not found
# configure.ac:898: required file `py/Boinc/version.py.in' not found
Patch8:         boinc-configure.patch
BuildRequires:  Mesa-devel
BuildRequires:  docbook2x
BuildRequires:  docbook_4
BuildRequires:  fdupes
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gettext-runtime
BuildRequires:  libcurl-devel >= 7.17.1
BuildRequires:  libjpeg-devel
BuildRequires:  libnotify-devel
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  mysql-devel
BuildRequires:  openssl-devel
BuildRequires:  pkg-config
BuildRequires:  pwdutils
BuildRequires:  python-mysql
BuildRequires:  sqlite3-devel
BuildRequires:  systemd
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-devel >= 2.8.0
BuildRequires:  xorg-x11-libXmu-devel
### FIXME:
## updating boinc-client or boinc-manager does not update libboinc6
## hence we define this dependency
## !! Do not remove this dependency !!
Requires:       libboinc%{soname} = %{version}-%{release}
Recommends:     boinc-client-lang = %{version}
Recommends:     logrotate
Requires(pre):  pwdutils
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} >= 1310
BuildRequires:  libXScrnSaver-devel
BuildRequires:  libXi-devel
BuildRequires:  libxcb-devel
BuildRequires:  xcb-util-devel
%else
BuildRequires:  xorg-x11-libxcb-devel
%endif
%lang_package
%lang_package -n boinc-manager

%description
The Berkeley Open Infrastructure for Network Computing (BOINC) is an open-
source software platform which supports distributed computing, primarily in
the form of "volunteer" computing and "desktop Grid" computing.  It is well
suited for problems which are often described as "trivially parallel".  BOINC
is the underlying software used by projects such as SETI@home, Einstein@Home,
ClimatePrediciton.net, the World Community Grid, and many other distributed
computing projects.

This package installs the BOINC client software, which will allow your
computer to participate in one or more BOINC projects, using your spare
computer time to search for cures for diseases, model protein folding, study
global warming, discover sources of gravitational waves, and many other types
of scientific and mathematical research.

%package -n boinc-manager
Summary:        GUI to control and monitor boinc-client
Group:          Productivity/Scientific/Astronomy
Recommends:     boinc-manager-lang = %{version}
Requires:       hicolor-icon-theme

%description -n boinc-manager
The BOINC Manager is a graphical monitor and control utility for the BOINC
core client. It gives a detailed overview of the state of the client it is
monitoring. The BOINC Manager has two modes of operation, the "Simple View" in
which it only displays the most important information and the "Advanced View"
in which all information and all control elements are available.

%package devel
Summary:        Development files for boinc-client
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}
Requires:       mysql-devel
Requires:       openssl-devel

%description devel
This package contains development files for %{name}.

%package -n libboinc%{soname}
Summary:        Shared Libs for %{name}
Group:          System/Libraries

%description -n libboinc%{soname}
The BOINC Manager is a graphical monitor and control utility for the BOINC
core client. It gives a detailed overview of the state of the client it is
monitoring. The BOINC Manager has two modes of operation, the "Simple View" in
which it only displays the most important information and the "Advanced View"
in which all information and all control elements are available.

%package doc
Summary:        Documentation files for %{name}
Group:          Documentation/Other
BuildArch:      noarch

%description doc
This package contains documentation files for %{name}.

%prep
%setup -q -n boinc-%{version} -D -a 1
%patch0
%patch2
%patch4
%patch7
%patch8

# Install user hints
install -m0644 %{SOURCE3} README.SUSE

# Fix lang directories (refer patch2)
mv locale/pt_PT locale/pt
mv locale/sv_SE locale/sv

# fix warning: deprecated conversion from string constant to 'char*'
pushd clientgui/common/
sed -i 's/static char/static const char/g' wxFlatNotebookImages.h
popd
pushd clientgui/res/
sed -i 's/static char/static const char/g' *.xpm
popd
pushd clientgui/res/skins/default/graphic/
sed -i 's/static char/static const char/g' *.xpm
popd

# fix utf8
iconv -f ISO88591 -t UTF8 < checkin_notes_2005 > checkin_notes_2005.utf8
touch -r checkin_notes_2005 checkin_notes_2005.utf8
mv checkin_notes_2005.utf8 checkin_notes_2005

iconv -f ISO88591 -t UTF8 < checkin_notes_2009 > checkin_notes_2009.utf8
touch -r checkin_notes_2009 checkin_notes_2009.utf8
mv checkin_notes_2009.utf8 checkin_notes_2009

iconv -f ISO88591 -t UTF8 < checkin_notes_2010 > checkin_notes_2010.utf8
touch -r checkin_notes_2010 checkin_notes_2010.utf8
mv checkin_notes_2010.utf8 checkin_notes_2010

# fix permissions and newlines on source files
chmod 644 clientgui/{DlgItemProperties.h,AsyncRPC.cpp,DlgItemProperties.cpp}
sed -i 's/\r//' clientgui/DlgItemProperties.cpp

### bnc#745656
## remove files with questionable licenses
# removing NVIDIA owned file that does not clearly allow redistribution or
# modification
rm coprocs/NVIDIA/include/nvapi.h
# removing unnecessary APSL licensed files
rm client/app_stats_mac.cpp

%build
#remove run libtoolize and ./_autosetup
%{_bindir}/libtoolize --force
./_autosetup

%configure \
  --disable-static \
  --enable-dynamic-client-linkage \
  --disable-server \
  --disable-fcgi \
  --enable-unicode \
  --with-ssl \
  --with-x

# Disable rpaths
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

# Export Path and make
make clean %{?_smp_mflags}
make libboinc_la_LIBADD="-L%{_libdir} -lssl -ldl" \
   CFLAGS="%{optflags} -g -W -pipe -fno-strict-aliasing -D_REENTRANT" \
   CXXFLAGS="%{optflags} -g -W -pipe -fno-strict-aliasing -D_REENTRANT" \
   DESTDIR=%{_prefix} %{?_smp_mflags}

### hmm, boincmgr is not build by default (but stated in configure)
# BOINC Default enable values
#   --enable-server --enable-client --enable-libraries
#   --enable-manager: builds server, client, and libraries
#
# hence we jump into clientgui and build it manually
pushd clientgui
make libboinc_la_LIBADD="-L%{_libdir} -lssl -ldl" \
   CFLAGS="%{optflags} -g -W -pipe -fno-strict-aliasing -D_REENTRANT -lgtk-x11-2.0" \
   CXXFLAGS="%{optflags} -g -W -pipe -fno-strict-aliasing -D_REENTRANT -lgtk-x11-2.0" \
   DESTDIR=%{_prefix} %{?_smp_mflags}
popd
pushd locale
make %{?_smp_mflags}
popd

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
for i in clientgui locale; do
  pushd $i
  make DESTDIR=%{buildroot} install %{?_smp_mflags}
  popd
done

# Creates default folders
install -dm0755 %{buildroot}%{boinc_dir}
install -dm0755 %{buildroot}%{_mandir}/man1

# Remove old boinc & rename boinc_client to boinc-client
rm -f %{buildroot}%{_bindir}/boinc
mv -f %{buildroot}%{_bindir}/boinc_client %{buildroot}%{_bindir}/%{name}

# Rename boincmgr and wrap it
mv %{buildroot}%{_bindir}/boincmgr %{buildroot}%{_bindir}/boinc-gui

# Install boinc-manager wrapper script
install -Dm0755 %{SOURCE6} %{buildroot}%{_bindir}/boinc-manager

# Use symlink instead of hardlink
pushd %{buildroot}%{_bindir}
ln -s -f %{name} boinc
ln -s -f boinc-manager boincmgr
ln -s -f boinc-manager boincmanager
popd

# replace @boinc_dir@, @bindir@
sed -i \
  -e "s,@boinc_dir@,%{boinc_dir},g" \
  -e "s,@bindir@,%{_bindir},g" \
  %{buildroot}%{_bindir}/boinc-manager

# Remove /etc/sysconfig/boinc-client, it is added by %%fillup_and_insserv
rm -f %{buildroot}%{_sysconfdir}/sysconfig/%{name}

# Install init and create symlink for rcboinc
install -D -m0644 %{SOURCE20} %{buildroot}%{_unitdir}/%{name}.service
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
# And remove sysvinit script installed by boinc
rm -r %{buildroot}/%{_initddir}

# Install logrotate
install -Dm0644 %{SOURCE5} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

# Install bash completion
install -Dpm0644 client/scripts/boinc.bash %{buildroot}%{_sysconfdir}/bash_completion.d/boinc

# Install desktop-file and icons
install -Dm0644 boinc-gui-128.png %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/boinc-gui.png
install -Dm0644 boinc-gui-64.png %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/boinc-gui.png
install -Dm0644 boinc-gui-48.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/boinc-gui.png
install -Dm0644 boinc-gui-32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/boinc-gui.png
install -Dm0644 boinc-gui-22.png %{buildroot}%{_datadir}/icons/hicolor/22x22/apps/boinc-gui.png
install -Dm0644 boinc-gui-16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/boinc-gui.png

# install icons
install -m0644 clientgui/res/boincmgr.16x16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/boincmanager.png
install -m0644 clientgui/res/boincmgr.32x32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/boincmanager.png
install -m0644 clientgui/res/boincmgr.48x48.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/boincmanager.png

# Install *.desktop File
%suse_update_desktop_file -i boinc-gui Utility

# Remove static libraries, libtool archives
rm %{buildroot}%{_libdir}/*.{a,la}

# Relinking Manpages
ln -s -f boincmgr.1.gz %{buildroot}%{_mandir}/man1/boinc-manager.1.gz
ln -s -f boinccmd.1.gz %{buildroot}%{_mandir}/man1/boinccmd.1.gz
ln -s -f boinc.1.gz %{buildroot}%{_mandir}/man1/boinc.1.gz

# Fix spurious-executable-perm
chmod 0644 doc/*.php

# Install fake /var/lib/boinc
install -dm0755 %{buildroot}%{_var}/lib/boinc

# Prepare $LANG Packages
%find_lang BOINC-Client
%find_lang BOINC-Manager

%fdupes -s %{buildroot}

%pre
# add group
%{_sbindir}/groupadd -r boinc 2>/dev/null || :
# add user
%{_sbindir}/useradd -c "BOINC Client" -d "%{_localstatedir}/lib/boinc" \
  -g boinc -r -s /sbin/nologin boinc 2>/dev/null || :
if [ -f %{_sysconfdir}/sysconfig/%{name} ]; then
  if grep "BOINC_BOINC_USR" %{_sysconfdir}/sysconfig/boinc-client | grep -q grep; then
    mv -f %{_sysconfdir}/sysconfig/%{name} %{_sysconfdir}/sysconfig/%{name}.save
  fi
fi
%service_add_pre %{name}.service

%preun
%service_del_preun %{name}.service

%post
%service_add_post %{name}.service
%{_sbindir}/usermod -c "BOINC Client" -s /sbin/nologin boinc 2>/dev/null || :

%postun
%service_del_postun %{name}.service

%post -n boinc-manager
%{_bindir}/touch --no-create %{_datadir}/icons/hicolor || :
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi

%postun -n boinc-manager
%{_bindir}/touch --no-create %{_datadir}/icons/hicolor || :
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi

%post -n libboinc%{soname} -p /sbin/ldconfig

%postun -n libboinc%{soname} -p /sbin/ldconfig

%post devel -p /sbin/ldconfig

%postun devel -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc COPYING* COPYRIGHT notes todo README.SUSE
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/bash_completion.d/*
%{_bindir}/boinc
%{_bindir}/%{name}
%{_bindir}/boinccmd
%{_bindir}/boincscr
%{_bindir}/switcher
%{_mandir}/man1/boinccmd.1.gz
%{_mandir}/man1/boinc.1.gz
%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}
%defattr(-,boinc,boinc,-)
%{_localstatedir}/lib/boinc/

%files doc
%defattr(-,root,root,-)
%doc checkin_*
%doc doc/*.txt doc/bolt doc/logo doc/*.php doc/*.png doc/*.html

%files -n boinc-manager
%defattr(-,root,root,-)
%{_bindir}/boinc-gui
%{_bindir}/boinc-manager
%{_bindir}/boincmgr
%{_bindir}/boincmanager
%{_datadir}/applications/boinc-gui.desktop
%{_datadir}/icons/hicolor/*/apps/*
%{_mandir}/man1/boincmgr.1.gz
%{_mandir}/man1/boinc-manager.1.gz

%files -n %{name}-lang -f BOINC-Client.lang
%defattr(-,root,root)

%files -n boinc-manager-lang -f BOINC-Manager.lang
%defattr(-,root,root)

%files -n libboinc%{soname}
%defattr(-,root,root,-)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%{_libdir}/*.so
%{_includedir}/boinc

%changelog
* Wed Jun 24 2015 jengelh@inai.de
- boinc-client.service: replace ControlGroup= by Slice=, since
  ControlGroup is gone since systemd-205 already. We now use the
  "background.slice". Configuration of the background.slice is
  left to the administrator since it may be shared by other
  packages, and is subject to preferences. If you need some default
  to begin with for the first time,  use
  `systemctl set-property background.slice CPUShares=2`.
* Wed Mar 18 2015 jengelh@inai.de
- Reduce logrotate from Requires to Recommends.
- Remove Requires: cron. This seems only for the server parts
  (not in this package).
- Remove systemd requires to allow for a minimal container setup.
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Tue Jun 17 2014 tchvatal@suse.com
- Remove needless rpmlintrc lines to ease error spotting when there
  really are some.
* Tue Jun 17 2014 tchvatal@suse.com
- Cleanup with spec-cleaner for better readability
- Move lang packages from Requires to Recommends
* Tue Jun 17 2014 tchvatal@suse.com
- Remove unused patch:
  * boinc-completion.patch
- Remove comments with unused patches
- Remove conditionals with inits as we don't build for such release
  anyway
- Provide rcboinc symlink for easier usage.
* Wed Mar 26 2014 chris@computersalat.de
- some RPMLINT fixes
  * fix License: remove ','
  * non-standard-gid /var/lib/boinc boinc
  * SR #227671 to rpmlint
- fix deps for libxcb
* Tue Mar 18 2014 chris@computersalat.de
- fix README.SUSE
* Sun Mar 16 2014 chris@computersalat.de
  [#] fix for bnc#779335
  * disabled boinc-completion.patch
- update to 7.2.42
  * Fix problem that was causing scheduler RPCs to fail on Yoyo@home
    (HTTP status code 400)
  * for mor info have a look at
    http://boinc.berkeley.edu/wiki/Release_Notes
- removed obsolete patches:
  * boinc-client-dynamic_buffers.patch
  * boinc-init.patch
  * boinc-client-7.0.36-AM_CONDITIONAL.patch
  * boinc-client-7.0.36-dynamic_buffers.patch
- rebased patches:
  * boinc-LC_MESSAGES.patch
  * boinc-client-AM_CONDITIONAL.patch
  * boinc-configure.patch
  * boinc-docbook2x.patch
  * boinc-guirpcauth.patch
* Sat Oct 26 2013 p.drouand@gmail.com
- Update to version 7.0.36
  + No changelog available
- Add systemd support
- Adapt patchs to upstream changes
  * boinc-client-dynamic_buffers.patch
  * boinc-client-AM_CONDITIONAL.patch
- Remove boinc-client-glib_h.patch; fixed on upstream
- Do not copy INSTALL in documentation
* Wed May  1 2013 chris@computersalat.de
- update to 7.0.28
  * sorry but there is no ChangeLog :(
- rebase patches
  * dynamic_buffers, guirpcauth, AM_CONDITIONAL
- add configure patch
- remove obsolete glib_h patch
* Wed Apr  3 2013 coolo@suse.com
- do not own bash directories
* Tue Jul 10 2012 chris@computersalat.de
- rename patch
  * fix-automake-conditional to boinc-client-AM_CONDITIONAL patch
- fix build for SLE_11
  * AM_CONDITIONAL patch >= 12.2
* Tue Jul 10 2012 coolo@suse.com
- fix compilation for factory and 12.2
* Sun Jul  1 2012 chris@computersalat.de
- add BOINC_DIR to sysconfig
  * make BOINC_DIR configurable (a proposal of Carsten Neumann)
* Sat Feb 11 2012 chris@computersalat.de
- add glib_h patch
* Fri Feb 10 2012 chris@computersalat.de
- update tp 6.12.43
  * sorry but there is no ChangeLog :(
- rework patches
- remove obsolete patches
  * boinc-server.patch
  * boinc-client-str_util.patch
- add boinc-client-lang subpkg
- fix DSOLinkChange for suse >= 1210
  * see https://fedoraproject.org/wiki/UnderstandingDSOLinkChange
    for more info, special thanks to Stefan Dirsch :)
* Fri Feb 10 2012 chris@computersalat.de
- fix sed for boinc-manager
* Wed Feb  8 2012 chris@computersalat.de
- fix for bnc#745887 ( Confirm licensing of boinc-client 6.10.60 )
- fix for bnc#744612 ( File /usr/bin/boinc_gui incorrectly named )
- fix for bnc#744389 ( boinc-client will not run )
- fix for bnc#732118 ( BOINC installs but will not run )
* Mon Feb  6 2012 chris@computersalat.de
- fix License (http://www.spdx.org/licenses/)
  * LGPL-3.0
* Sun Feb  5 2012 chris@computersalat.de
- remove client dep of manager
  * manager does not really need a local boinc-client ;)
- fix desktop file
* Sat Feb  4 2012 chris@computersalat.de
- fix deps for boinc-client
  * Requires libboinc6
* Thu Feb  2 2012 chris@computersalat.de
- rework patches
- rework sysconfig file
- rework logrotate file
- add SuSElike init script
- fix user add
  * boinc needs a shell
- fix wrapper
  * replace boincmanager with boinc-manager and add symlink for
    backward compatibility
  * fix boinc_gui -> boinc-gui
- fix License
  * LGPLv3
- fix for bnc#689499
  * a blocked boinc client, the manager works
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Tue Aug 30 2011 Sascha.Manns@open-slx.de
- fixed Bug bnc#714623 (/var/lock/subsys unsupported)
* Mon May 16 2011 pth@suse.de
- Avoid buffer overflow in filesys.cpp(dir_size).
* Sun May  1 2011 chris@computersalat.de
- update to 6.10.60
  * Fix: Project list issue in the attach wizard that lead to a crash
- fix deps
  o wxGTK-devel
- enable parallel build
* Fri Apr 29 2011 saigkill@opensuse.org
- filed shared-lib-calls-exit in boinc as
  http://boinc.berkeley.edu/trac/ticket/1098
- filed binary-or-shlib-calls-gethostbyname as
  http://boinc.berkeley.edu/trac/ticket/1099
* Thu Apr 28 2011 saigkill@opensuse.org
- Rewritten the Spec based on Malcolm Lewis Improvements (THX)
* Wed Apr 27 2011 saigkill@opensuse.org
- Removed boinc-bnc_465676.patch (Fixed Upstream)
- Removed boinc-bnc_465676.patch (Fixed Upstream)
- Removed boinc-client-NotebookWxPanel.patch (Fixed Upstream)
- Removed boinc-client-wxWindowListNode.patch (Fixed Upstream)
* Tue Dec 28 2010 sbrabec@suse.cz
- Compile with wxWidgets (STL variant).
* Tue Oct  5 2010 malcolmlewis@opensuse.org
- Fix boinc-manager-lang requires
* Tue Oct  5 2010 malcolmlewis@opensuse.org
- Major spec file makeover
- Updated version
- Cleaned up patches
- Fixed most deprecated conversion from string constant to 'char*'
* Mon Mar 15 2010 coolo@novell.com
- disable use of %%jobs
* Sun May 31 2009 saigkill@opensuse.org
- fixed str_util.h while using newer gcc (THX to Jan)
* Fri May 22 2009 saigkill@opensuse.org
- fixed Errors while using newer wx Version
* Fri Mar 27 2009 saigkill@opensuse.org
- removed boinctray depency
* Sat Mar 14 2009 saigkill@opensuse.org
- added rpmlintrc
* Wed Feb 25 2009 pth@suse.de
- Use wxWindowList::compatibility_iterator instead of wxWindowListNode*
  as the latter is not defined when wxWindows is compiled to use
  the STL.
- Include standard compiler flags.
- Reformat description
- Correct spelling boinc-client-README.SuSE
* Thu Feb 12 2009 saigkill@opensuse.org
- added wxstring_conversion.patch (fix Bug #774 Berkeley Bug)
* Wed Feb 11 2009 saigkill@opensuse.org
- first stable Version
- fixed boincmgr to copy gui_rpc_auth.cfg to every /home
* Wed Feb 11 2009 saigkill@opensuse.org
- Export %%%%changelog to boinc-client.changes
* Tue Feb 10 2009 saigkill@opensuse.org
- changed $BOINCEXE from boinc_client to boinc
* Wed Feb  4 2009 saigkill@opensuse.org
- Fixed OpenSUSE Bugzilla Bug #468414
* Tue Feb  3 2009 saigkill@opensuse.org
- updated to Version 6.4
- deleted bnc_465676 (was fixed in sourcecode by boinc-team)
* Mon Feb  2 2009 dl9pf@gmx.de
- tweaked -doc package
* Mon Feb  2 2009 saigkill@opensuse.org
- added README.SuSE to %%%%doc
- added own Patches:
  + boinc-docbook2x (fix using docbook2x)
  + boinc-LC_MESSAGES (fix handling .mo LC Messages)
  + boinc-rcscript (fix using init.d instead of rc.d)
  (fix BOINC User root)
  + boinc-sysconfig (fix installing conf in /etc/boinc-client.conf)
  (fix init File as boinc)
  + ca_cert_deactivate (fix deactivate using of ca_cert)
  + fs_start_included (fix add $fs_network to init.d Script)
* Sun Feb  1 2009 saigkill@opensuse.org
- added fillup Macro to use sysconfig
- use sysconfig.boinc as source from fillup macro
* Sat Jan 31 2009 saigkill@opensuse.org
- deleted bnc_431510 not relevant (for Mac).
- deleted bnc_439037 not relevant
- deleted bnc_442904 for Win. In my Package no Win/Mac Source
- added bnc_465676.patch fix CVE-ID: CVE-2009-0126
- branched for Factory:Contrib
* Fri Jan 23 2009 saigkill@opensuse.org
- deleted mac/mac_build/win Folders from the Sourcecode
* Wed Jan 14 2009 mauro@suse.de
- Added bnc_465676.patch to fix bnc#465676.
  + Fixes CVE-2008-5077
  + check return values of RSA_*() functions.
  + fix a memory leak, missing RSA_free().
* Tue Dec 23 2008 mauro@suse.de
- Added bnc_442904.patch to fix bnc#442904.
  + Use the proper delete.
* Mon Nov  3 2008 mauro@suse.de
- Add bnc_439037.patch to fix bnc#439037. We now use strcmp
  instead of the original ==.
* Fri Oct  3 2008 mauro@suse.de
- Add bnc-431510.patch to fix bnc#431510.
* Mon Sep  8 2008 mauro@suse.de
- initial package for SuSE. boinc 6.2.18 (based on the enzokiel's
  (opensuse version).
